Models (models package)
=======================

Base class Model
-------------------------

.. automodule:: gadma.models.model
   :members:
   :undoc-members:
   :show-inheritance:

Combinations of variables
-------------------------------------------

Base class VariablesCombination
*******************************
.. autoclass:: gadma.models.variables_combinations.VariablesCombination
   :members:
   :undoc-members:
   :show-inheritance:

Base class BinaryOperation
*******************************
.. autoclass:: gadma.models.variables_combinations.BinaryOperation
   :members:
   :undoc-members:
   :show-inheritance:

Classes of different binary operations
**************************************
.. automodule:: gadma.models.variables_combinations
   :members: Addition, Subtraction, Multiplication, Division
   :undoc-members:
   :show-inheritance:

Events
-------------------------------------------
.. automodule:: gadma.models.event
   :members: Event, Epoch, Split
   :undoc-members:
   :show-inheritance:

Demographic models
----------------------

Base class DemographicModel
*******************************

.. automodule:: gadma.models.demographic_model
   :noindex:
   :members: DemographicModel
   :undoc-members:
   :show-inheritance:

Class EpochDemographicModel
*******************************

.. automodule:: gadma.models.demographic_model
   :members: EpochDemographicModel
   :undoc-members:
   :show-inheritance:

Class StructureDemographicModel
*******************************

.. automodule:: gadma.models.structure_demographic_model
   :members:
   :undoc-members:
   :show-inheritance:

Class CustomDemographicModel
*******************************

.. automodule:: gadma.models.custom_demographic_model
   :members:
   :undoc-members:
   :show-inheritance:

